store_words

Function store_words 

pub fn store_words(
    cpu: &mut Cpu,
    scheme: InstructionScheme,
) -> OperationResult<()>
0x0301 store_words:target [start:end]

Target

  • The register containing the address from whom to write to.

Arguments

  • Range($start, $end)

Operation

  • MEM[REG[$target]; ($end-$start)] = REG[$start..=$end]

To store only one register into memory, just make $start == $end.

Errors