pop

Function pop 

pub fn pop(cpu: &mut Cpu, scheme: InstructionScheme) -> OperationResult<()>
0x0211 pop:unsigned

Target

  • The bank register to write the value to pop from the stack.

Arguments

  • None

Operation

  • pop a value from the stack and put it into REG[$target].

Errors