pub fn pop(cpu: &mut Cpu, scheme: InstructionScheme) -> OperationResult<()>Expand description
0x0211 pop:unsigned
Target
- The bank register to write the value to pop from the stack.
Arguments
- None
Operation
- pop a value from the stack and put it into
REG[$target].
Errors
- OperationError::InvalidArgumentType if the provided argument is not an ArgumentType::NoArgument,